import './menu-tree-with-top-button.css';
import MenuTree from "./MenuTree.tsx";
import {IMenuTreeItem} from "../../interfaces/menu/IMenuTree.ts";
import {useState} from "react";

class MenuTreeItem implements IMenuTreeItem {
    children: Array<IMenuTreeItem> | null;
    id: string;
    isEdit: boolean;
    isOpen: boolean;
    isParent: boolean;
    level: number;
    name: string;
    oldName: string;

    constructor(id: string, name: string, level: number) {
        this.id = id;
        this.name = name;
        this.oldName = name;
        this.level = level;
        this.isEdit = false;
        this.isOpen = false;
        this.isParent = false;
        this.children = null;
    }

}

export default function MenuTreeWithTopButton() {

    const menuTrees: Array<IMenuTreeItem> = [];
    const [menuTreeArray, setMenuTreeArray] = useState(menuTrees);

    return (
        <div className="menu-tree-with-top-button">
            <button type="button" className="btn btn-orange" onClick={() => {
                const menuTreeItem = new MenuTreeItem(`${new Date().getTime()}`, '一级目录', 1);
                menuTreeItem.isParent = true;
                setMenuTreeArray([
                    ...menuTreeArray,
                    menuTreeItem,
                ]);
            }}>添加目录
            </button>
            <MenuTree
                menus={menuTreeArray}
                url={''}
                setMenuTreeArray={() => {
                    setMenuTreeArray([
                        ...menuTreeArray
                    ])
                }}
                handleExpand={() => {
                }}
                handleAddClick={(item) => {
                    item.isParent = true;
                    item.isOpen = true;
                    if (!item.children) {
                        item.children = new Array<IMenuTreeItem>();
                    }
                    const menuTreeItem = new MenuTreeItem(`${new Date().getTime()}`, item.level + '级目录', item.level + 1);
                    menuTreeItem.isOpen = true;
                    item.children.push(menuTreeItem);
                    setMenuTreeArray([
                        ...menuTreeArray
                    ])
                }
                }
                handleEditClick={(item) => {
                    item.isEdit = true;
                    setMenuTreeArray([
                        ...menuTreeArray
                    ])
                }}
                handleRemoveClick={(_item, index, parent) => {
                    if (parent) {
                        parent?.children?.splice(index, 1);
                    } else {
                        menuTreeArray.splice(index, 1);
                    }
                    setMenuTreeArray([
                        ...menuTreeArray
                    ])
                }}
                handleEditSaveClick={(item) => {
                    // 这里发请求，成功之后修改，失败还原
                    if (item.name === '') {
                        return;
                    }
                    item.oldName = item.name;
                    item.isEdit = false;
                    setMenuTreeArray([
                        ...menuTreeArray
                    ])
                }}
                handleEditCancelClick={(item) => {
                    item.name = item.oldName;
                    item.isEdit = false;
                    setMenuTreeArray([
                        ...menuTreeArray
                    ])
                }}
                handleNameChange={() => {
                    setMenuTreeArray([
                        ...menuTreeArray
                    ])
                }}
            />
        </div>
    )
}